
# Slot: coexpressed with


holds between any two genes or gene products, in which both are generally expressed within a single defined experimental context.

URI: [biolink:coexpressed_with](https://w3id.org/biolink/vocab/coexpressed_with)


## Domain and Range

[GeneOrGeneProduct](GeneOrGeneProduct.md) &#8594;  <sub>0..\*</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [correlated with](correlated_with.md)

## Children


## Used by

